@@ -382,13 +382,13 @@ class maybe_buffered_partd(object):
                 if self.compression
                 else None
             )
-        except AttributeError:
+        except AttributeError as e:
             raise ImportError(
                 "Not able to import and load {0} as compression algorithm."
                 "Please check if the library is installed and supported by Partd.".format(
                     self.compression
                 )
-            )
+            ) from e
         file = partd.File(path)
         partd.file.cleanup_files.append(path)
         # Envelope partd file with compression, if set and available
