@@ -718,9 +718,6 @@ def test_set_index_sorted_true():
     with pytest.raises(ValueError):
         a.set_index(a.z, sorted=True)
 
-    with pytest.warns(UserWarning):
-        a.set_index(a.y, sorted=True)
-
 
 def test_set_index_sorted_single_partition():
     df = pd.DataFrame({"x": [1, 2, 3, 4], "y": [1, 0, 1, 0]})
@@ -796,7 +793,7 @@ def test_set_index_categorical():
 
 
 def test_compute_divisions():
-    from dask.dataframe.shuffle import compute_divisions
+    from dask.dataframe.shuffle import compute_and_set_divisions
 
     df = pd.DataFrame(
         {"x": [1, 2, 3, 4], "y": [10, 20, 20, 40], "z": [4, 3, 2, 1]},
@@ -805,18 +802,11 @@ def test_compute_divisions():
     a = dd.from_pandas(df, 2, sort=False)
     assert not a.known_divisions
 
-    divisions = compute_divisions(a)
-    b = copy(a)
-    b.divisions = divisions
+    b = compute_and_set_divisions(copy(a))
 
     assert_eq(a, b, check_divisions=False)
     assert b.known_divisions
 
-    c = dd.from_pandas(df.set_index("y"), 2, sort=False)
-    # Partitions overlap warning
-    with pytest.warns(UserWarning):
-        compute_divisions(c)
-
 
 def test_empty_partitions():
     # See https://github.com/dask/dask/issues/2408
@@ -973,3 +963,40 @@ def test_disk_shuffle_check_actual_compression():
     compressed_data = generate_raw_partd_file(compression="BZ2")
 
     assert len(uncompressed_data) > len(compressed_data)
+
+
+@pytest.mark.parametrize("ignore_index", [None, True, False])
+@pytest.mark.parametrize(
+    "on", ["id", "name", ["id", "name"], pd.Series(["id", "name"])]
+)
+@pytest.mark.parametrize("max_branch", [None, 4])
+def test_dataframe_shuffle_on_tasks_api(on, ignore_index, max_branch):
+    # Make sure DataFrame.shuffle API returns the same result
+    # whether the ``on`` argument is a list of column names,
+    # or a separate DataFrame with equivalent values...
+    df_in = dask.datasets.timeseries(
+        "2000",
+        "2001",
+        types={"value": float, "name": str, "id": int},
+        freq="2H",
+        partition_freq="1M",
+        seed=1,
+    )
+    if isinstance(on, str):
+        ext_on = df_in[[on]].copy()
+    else:
+        ext_on = df_in[on].copy()
+    df_out_1 = df_in.shuffle(
+        on, shuffle="tasks", ignore_index=ignore_index, max_branch=max_branch
+    )
+    df_out_2 = df_in.shuffle(ext_on, shuffle="tasks", ignore_index=ignore_index)
+
+    assert_eq(df_out_1, df_out_2)
+
+
+def test_set_index_overlap():
+    A = pd.DataFrame({"key": [1, 2, 3, 4, 4, 5, 6, 7], "value": list("abcd" * 2)})
+    a = dd.from_pandas(A, npartitions=2)
+    a = a.set_index("key", sorted=True)
+    b = a.repartition(divisions=a.divisions)
+    assert_eq(a, b)
